mappingObject = {
    "amazon_campaigns": "graas_amazon_campaigns",
    "flipkart_campaigns": "graas_flipkart_campaigns",
    "affiliate_report_daily": "graas_mkp_affiliate_report_daily",
    "deals_overview_daily": "graas_mkp_deals_overview_daily",
    "deals_trends_daily": "graas_mkp_deals_trends_daily",
    "offsite_campaigns": "graas_mkp_offsite_campaigns",
    "onsite_campaigns": "graas_mkp_onsite_campaigns",
    "onsite_keywords": "graas_mkp_onsite_keywords",
    "product_campaign_performance": "graas_mkp_product_campaign_performance",
    "product_overview_daily": "graas_mkp_product_overview_daily",
    "product_overview_hourly": "graas_mkp_product_overview_hourly",
    "product_performance": "graas_mkp_product_performance",
    "shop_stats_daily": "graas_mkp_shop_stats_daily",
    "shop_stats_hourly": "graas_mkp_shop_stats_hourly",
    "traffic_overview_daily": "graas_mkp_traffic_overview_daily",
    "traffic_overview_hourly": "graas_mkp_traffic_overview_hourly",
    "voucher_performance_daily": "graas_mkp_voucher_performance_daily",
}
